@@ -1,3 +1,4 @@
+import os
 import sys
 
 from scrapy import log
@@ -6,24 +7,25 @@ from scrapy.conf import settings
 from utils import get_client
 
 class SentryMiddleware(object):
-    def __init__(self, dsn=None):
-        self.client = get_client(dsn)
-
-    @classmethod
-    def from_settings(cls, settings):
-        dsn = settings.get("SENTRY_DSN", None)
-        return cls(dsn)
+    def __init__(self, dsn=None, client=None):
+        self.client = client if client else get_client(dsn)
 
     @classmethod
     def from_crawler(cls, crawler):
-        return cls.from_settings(crawler.settings)
+        dsn = os.environ.get("SENTRY_DSN", crawler.settings.get("SENTRY_DSN", None))
+        if dsn is None:
+            raise NotConfigured('No SENTRY_DSN configured')
+        return cls(dsn)
 
     def trigger(self, exception, spider=None, extra={}):
+        extra = {
+                'spider': spider.name if spider else "",
+            }
         msg = self.client.captureException(exc_info=sys.exc_info(), extra=extra)
         ident = self.client.get_ident(msg)
-        
-        log.msg("Follow last exception in Sentry '%s'" % ident, 
-                level=log.INFO, spider=spider)
+
+        l = spider.log if spider else log.msg
+        l("Sentry Exception ID '%s'" % ident, level=log.INFO)
 
         return None
         
